]> git.cameronkatri.com Git - mandoc.git/blobdiff - mandoc.h
garbage collect two unused enum mandocerr items
[mandoc.git] / mandoc.h
index 5170b419b90739f541d3c2d32ca09ec1978d2f1c..6056ab5a63a042c513200562e1621485785c7294 100644 (file)
--- a/mandoc.h
+++ b/mandoc.h
@@ -1,7 +1,7 @@
-/*     $Id: mandoc.h,v 1.111 2013/10/05 20:30:05 schwarze Exp $ */
+/*     $Id: mandoc.h,v 1.124 2014/06/30 23:45:07 schwarze Exp $ */
 /*
  * Copyright (c) 2010, 2011 Kristaps Dzonsons <kristaps@bsd.lv>
- * Copyright (c) 2012, 2013 Ingo Schwarze <schwarze@openbsd.org>
+ * Copyright (c) 2010-2014 Ingo Schwarze <schwarze@openbsd.org>
  *
  * Permission to use, copy, modify, and distribute this software for any
  * purpose with or without fee is hereby granted, provided that the above
@@ -20,6 +20,7 @@
 
 #define ASCII_NBRSP     31  /* non-breaking space */
 #define        ASCII_HYPH       30  /* breakable hyphen */
+#define        ASCII_BREAK      29  /* breakable zero-width space */
 
 /*
  * Status level.  This refers to both internal status (i.e., whilst
@@ -48,19 +49,21 @@ enum        mandocerr {
        MANDOCERR_WARNING, /* ===== start of warnings ===== */
 
        /* related to the prologue */
-       MANDOCERR_NOTITLE, /* no title in document */
-       MANDOCERR_UPPERCASE, /* document title should be all caps */
-       MANDOCERR_BADMSEC, /* unknown manual section */
-       MANDOCERR_BADVOLARCH, /* unknown manual volume or arch */
-       MANDOCERR_NODATE, /* date missing, using today's date */
-       MANDOCERR_BADDATE, /* cannot parse date, using it verbatim */
-       MANDOCERR_PROLOGOOO, /* prologue macros out of order */
-       MANDOCERR_PROLOGREP, /* duplicate prologue macro */
-       MANDOCERR_BADPROLOG, /* macro not allowed in prologue */
-       MANDOCERR_BADBODY, /* macro not allowed in body */
+       MANDOCERR_TH_MISSING, /* no TH macro in document */
+       MANDOCERR_TITLE_CASE, /* document title should be all caps */
+       MANDOCERR_MSEC_BAD, /* unknown manual section */
+       MANDOCERR_ARCH_BAD, /* unknown manual volume or arch */
+       MANDOCERR_DATE_MISSING, /* date missing, using today's date */
+       MANDOCERR_DATE_BAD, /* cannot parse date, using it verbatim */
+       MANDOCERR_PROLOG_ORDER, /* prologue macros out of order */
+       MANDOCERR_PROLOG_REP, /* duplicate prologue macro */
+       MANDOCERR_PROLOG_BAD, /* macro not allowed in prologue: macro */
+       MANDOCERR_PROLOG_ONLY, /* macro not allowed in body: macro */
 
        /* related to document structure */
-       MANDOCERR_SO, /* .so is fragile, better use ln(1) */
+       MANDOCERR_SO, /* .so is fragile, better use ln(1): .so path */
+       MANDOCERR_DOC_EMPTY, /* no document body */
+       MANDOCERR_SEC_BEFORE, /* content before the first section header */
        MANDOCERR_NAMESECFIRST, /* NAME section must come first */
        MANDOCERR_BADNAMESEC, /* bad NAME section contents */
        MANDOCERR_SECOOO, /* sections out of conventional order */
@@ -103,12 +106,9 @@ enum       mandocerr {
        MANDOCERR_BADTAB, /* tab in non-literal context */
        MANDOCERR_EOLNSPACE, /* end of line whitespace */
        MANDOCERR_BADCOMMENT, /* bad comment style */
-       MANDOCERR_BADESCAPE, /* unknown escape sequence */
+       MANDOCERR_BADESCAPE, /* bad escape sequence */
        MANDOCERR_BADQUOTE, /* unterminated quoted string */
 
-       /* related to equations */
-       MANDOCERR_EQNQUOTE, /* unexpected literal in equation */
-
        MANDOCERR_ERROR, /* ===== start of errors ===== */
 
        /* related to equations */
@@ -148,20 +148,27 @@ enum      mandocerr {
        MANDOCERR_NUMERIC, /* request requires a numeric argument */
        MANDOCERR_LISTTYPE, /* missing list type */
        MANDOCERR_ARGSLOST, /* line argument(s) will be lost */
-       MANDOCERR_BODYLOST, /* body argument(s) will be lost */
 
        MANDOCERR_FATAL, /* ===== start of fatal errors ===== */
 
-       MANDOCERR_NOTMANUAL, /* manual isn't really a manual */
+       MANDOCERR_TOOLARGE, /* input too large */
+       MANDOCERR_NOTMANUAL, /* not a manual */
        MANDOCERR_COLUMNS, /* column syntax is inconsistent */
        MANDOCERR_BADDISP, /* NOT IMPLEMENTED: .Bd -file */
        MANDOCERR_SYNTARGVCOUNT, /* argument count wrong, violates syntax */
        MANDOCERR_SYNTCHILD, /* child violates parent syntax */
        MANDOCERR_SYNTARGCOUNT, /* argument count wrong, violates syntax */
-       MANDOCERR_SOPATH, /* NOT IMPLEMENTED: .so with absolute path or ".." */
-       MANDOCERR_NODOCBODY, /* no document body */
+       MANDOCERR_SO_PATH, /* NOT IMPLEMENTED: .so with absolute path or ".." */
+       MANDOCERR_SO_FAIL, /* .so request failed */
        MANDOCERR_NODOCPROLOG, /* no document prologue */
        MANDOCERR_MEM, /* static buffer exhausted */
+
+       /* ===== system errors ===== */
+
+       MANDOCERR_SYSOPEN, /* cannot open file */
+       MANDOCERR_SYSSTAT, /* cannot stat file */
+       MANDOCERR_SYSREAD, /* cannot read file */
+
        MANDOCERR_MAX
 };
 
@@ -231,6 +238,7 @@ struct      tbl_row {
        struct tbl_row   *next;
        struct tbl_cell  *first;
        struct tbl_cell  *last;
+       int               vert; /* trailing vertical line */
 };
 
 enum   tbl_datt {
@@ -353,7 +361,7 @@ struct      eqn_box {
 
 /*
  * An equation consists of a tree of expressions starting at a given
- * line and position. 
+ * line and position.
  */
 struct eqn {
        char             *name; /* identifier (or NULL) */
@@ -363,15 +371,12 @@ struct    eqn {
 };
 
 /*
- * The type of parse sequence.  This value is usually passed via the
- * mandoc(1) command line of -man and -mdoc.  It's almost exclusively
- * -mandoc but the others have been retained for compatibility.
+ * Parse options.
  */
-enum   mparset {
-       MPARSE_AUTO, /* magically determine the document type */
-       MPARSE_MDOC, /* assume -mdoc */
-       MPARSE_MAN /* assume -man */
-};
+#define        MPARSE_MDOC     1  /* assume -mdoc */
+#define        MPARSE_MAN      2  /* assume -man */
+#define        MPARSE_SO       4  /* honour .so requests */
+#define        MPARSE_QUICK    8  /* abort the parse early */
 
 enum   mandoc_esc {
        ESCAPE_ERROR = 0, /* bail! unparsable escape */
@@ -399,31 +404,24 @@ struct    man;
 
 __BEGIN_DECLS
 
-void            *mandoc_calloc(size_t, size_t);
-enum mandoc_esc          mandoc_escape(const char const **,
-                       const char const **, int *);
-void            *mandoc_malloc(size_t);
-void            *mandoc_realloc(void *, size_t);
-char            *mandoc_strdup(const char *);
-char            *mandoc_strndup(const char *, size_t);
+enum mandoc_esc          mandoc_escape(const char **, const char **, int *);
 struct mchars   *mchars_alloc(void);
 void             mchars_free(struct mchars *);
-char             mchars_num2char(const char *, size_t);
+char             mchars_num2char(const char *, size_t);
 int              mchars_num2uc(const char *, size_t);
-int              mchars_spec2cp(const struct mchars *, 
+int              mchars_spec2cp(const struct mchars *,
                        const char *, size_t);
-const char      *mchars_spec2str(const struct mchars *, 
+const char      *mchars_spec2str(const struct mchars *,
                        const char *, size_t, size_t *);
-struct mparse   *mparse_alloc(enum mparset, enum mandoclevel,
-                       mandocmsg, void *, char *);
+struct mparse   *mparse_alloc(int, enum mandoclevel, mandocmsg, char *);
 void             mparse_free(struct mparse *);
 void             mparse_keep(struct mparse *);
 enum mandoclevel  mparse_readfd(struct mparse *, int, const char *);
 enum mandoclevel  mparse_readmem(struct mparse *, const void *, size_t,
                        const char *);
 void             mparse_reset(struct mparse *);
-void             mparse_result(struct mparse *, 
-                       struct mdoc **, struct man **);
+void             mparse_result(struct mparse *,
+                       struct mdoc **, struct man **, char **);
 const char      *mparse_getkeep(const struct mparse *);
 const char      *mparse_strerror(enum mandocerr);
 const char      *mparse_strlevel(enum mandoclevel);